@@ -126,6 +126,25 @@ def pad_tiles(tiles, tile_size, tile_indices):
     return tiles
 
 
+def unpad_tiles(tiles):
+
+    tile_size = tiles.nonempty_tiles[0].shape[-2:]
+    tile_indices = tiles.tile_indices
+    tile_padding = (tile_size[0] - (tile_indices[0][-1, 1] - tile_indices[0][-1, 0]),
+                    tile_size[1] - (tile_indices[1][-1, 1] - tile_indices[1][-1, 0]))
+
+    tiles = tiles.copy()
+
+    if tile_padding[0] > 0:
+        for i, tile in enumerate(tiles[-1]):
+            tiles[-1, i] = tile[..., :-tile_padding[0], :]
+    if tile_padding[1] > 0:
+        for i, tile in enumerate(tiles[:, -1]):
+            tiles[i, -1] = tile[..., :-tile_padding[1]]
+
+    return tiles
+
+
 def compute_dask(tiles):
 
     for i, ts in enumerate(tiles):
